'use client';

import {
  Box,
  Button,
  Textarea,
  Input,
  Text,
  Heading,
  VStack,
  HStack,
  Grid,
  GridItem,
  Flex,
  Container,
 
  useColorModeValue,
  useToast,
  IconButton,
  Image,
  Card,
  CardHeader,
  CardBody,
  CardFooter,
  Avatar,
  SimpleGrid,
  Tag,
  TagLabel,
  TagLeftIcon,
  Link,
  FormControl,
  FormLabel,
  InputGroup,
  InputLeftElement,
} from '@chakra-ui/react';
import { useState, useEffect } from 'react';
import { STORY_STATUS, StoryStatus } from '../constants/status';
import { 
  CloseIcon, 
  AddIcon, 
  TimeIcon, 
  ChatIcon, 
  StarIcon, 
  SearchIcon, 
  AtSignIcon, 
  InfoIcon,
} from '@chakra-ui/icons';
import { FaMapMarkerAlt, FaUserAlt, FaHeading, FaCamera, FaPen } from 'react-icons/fa';
import Head from 'next/head';

interface Story {
  name: string;
  title: string;
  location: string;
  description: string;
  content: string;
  images?: string[];
  timestamp: string;
  status: StoryStatus;
  views?: number;
  likes?: number;
  tags?: string[];
}

export default function ShareExperiencePage() {
  const [stories, setStories] = useState<Story[]>([]);
  const [name, setName] = useState('');
  const [title, setTitle] = useState('');
  const [location, setLocation] = useState('');
  const [description, setDescription] = useState('');
  const [content, setContent] = useState('');
  const [images, setImages] = useState<string[]>([]);
  const [tags, setTags] = useState<string[]>([]);
  const [newTag, setNewTag] = useState('');
  const [featuredStories, setFeaturedStories] = useState<Story[]>([]);

  const toast = useToast();
  
  // Generate SEO-friendly page title
  const pageTitle = "Share Your Real-Life Experiences | Join Our Community Stories";
  const pageDescription = "Share your personal experiences and read authentic stories from our community. Connect with others through real-life adventures, lessons, and moments.";

  useEffect(() => {
    const saved = localStorage.getItem('stories');
    if (saved) {
      const parsedStories = JSON.parse(saved);
      setStories(parsedStories);
      
      // Set featured stories (first 3 approved stories)
      const approved = parsedStories.filter((s: { status: string; }) => s.status === STORY_STATUS.APPROVED);
      setFeaturedStories(approved.slice(0, 3));
    }

    if (navigator.geolocation) {
      navigator.geolocation.getCurrentPosition(
        position => {
          const { latitude, longitude } = position.coords;
          // Use reverse geocoding in a real app, but simplified here
          setLocation(`Lat: ${latitude.toFixed(4)}, Lng: ${longitude.toFixed(4)}`);
        },
        error => {
          console.warn('Location permission denied or error:', error.message);
        }
      );
    }
  }, []);

  const handleSubmit = () => {
    if (!name.trim() || !title.trim() || !description.trim() || !content.trim()) {
      toast({
        title: 'All required fields must be filled.',
        status: 'warning',
        isClosable: true,
      });
      return;
    }

    const newStory: Story = {
      name,
      title,
      location,
      description,
      content,
      images,
      timestamp: new Date().toLocaleString(),
      status: STORY_STATUS.PENDING,
      views: 0,
      likes: 0,
      tags: tags.length > 0 ? tags : ['Personal'],
    };

    const updated = [newStory, ...stories];
    setStories(updated);
    localStorage.setItem('stories', JSON.stringify(updated));

    // Reset form
    setName('');
    setTitle('');
    setDescription('');
    setContent('');
    setImages([]);
    setTags([]);

    toast({
      title: 'Story submitted!',
      description: 'Pending admin approval.',
      status: 'success',
      duration: 3000,
      isClosable: true,
    });
  };

  const handleImageUpload = (e: React.ChangeEvent<HTMLInputElement>) => {
    const files = Array.from(e.target.files || []);
    files.forEach(file => {
      const reader = new FileReader();
      reader.onloadend = () => {
        setImages(prev => [...prev, reader.result as string]);
      };
      reader.readAsDataURL(file);
    });
  };

  const handleRemoveImage = (index: number) => {
    setImages(prev => prev.filter((_, i) => i !== index));
  };

  const addTag = () => {
    if (newTag.trim() && !tags.includes(newTag.trim())) {
      setTags([...tags, newTag.trim()]);
      setNewTag('');
    }
  };

  const removeTag = (tagToRemove: string) => {
    setTags(tags.filter(tag => tag !== tagToRemove));
  };

  // Theme colors
  const bg = useColorModeValue('gray.50', 'gray.900');
  const cardBg = useColorModeValue('white', 'gray.800');
  const accentColor = useColorModeValue('teal.500', 'teal.300');
  const borderColor = useColorModeValue('gray.200', 'gray.700');
  const mutedTextColor = useColorModeValue('gray.600', 'gray.400');
  
  return (
    <>
      <Head>
        <title>{pageTitle}</title>
        <meta name="description" content={pageDescription} />
        <meta property="og:title" content={pageTitle} />
        <meta property="og:description" content={pageDescription} />
        <meta name="twitter:title" content={pageTitle} />
        <meta name="twitter:description" content={pageDescription} />
        <link rel="canonical" href="https://yourdomain.com/share-experience" />
      </Head>

      <Box minH="100vh" bg={bg}>
        <Container maxW="container.xl" py={8}>
          {/* Hero Section */}
          <Box 
            bg="teal.500" 
            color="white" 
            py={10} 
            px={6} 
            borderRadius="lg" 
            mb={8}
            backgroundImage="url('/images/hero-pattern.svg')"
            backgroundSize="cover" 
          >
            <Container maxW="container.md" textAlign="center">
              <Heading as="h1" size="2xl" mb={4}>
                Share Your Story
              </Heading>
              <Text fontSize="xl" mb={6}>
                Connect with others through your authentic experiences
              </Text>
              <Text fontSize="md" maxW="container.sm" mx="auto">
                Join thousands of others who have shared their moments, lessons, and adventures.
                Your story matters.
              </Text>
            </Container>
          </Box>

          {/* Featured Stories Section */}
          {featuredStories.length > 0 && (
            <Box mb={10}>
              <Heading as="h2" size="lg" mb={6}>
                Featured Stories
              </Heading>
              <SimpleGrid columns={{ base: 1, md: 3 }} spacing={6}>
                {featuredStories.map((story, i) => (
                  <Card key={i} overflow="hidden" variant="outline">
                    {story.images && story.images.length > 0 && (
                      <Box position="relative" h="200px">
                        <Image 
                          src={story.images[0]} 
                          alt={story.title}
                          objectFit="cover"
                          w="100%"
                          h="100%"
                        />
                        <Box 
                          position="absolute" 
                          bottom={0} 
                          w="100%" 
                          bg="blackAlpha.600" 
                          p={2}
                        >
                          <Text color="white" fontWeight="bold" isTruncated>
                            {story.title}
                          </Text>
                        </Box>
                      </Box>
                    )}
                    <CardBody>
                      {!story.images?.length && (
                        <Heading size="md" mb={2}>{story.title}</Heading>
                      )}
                      <Text noOfLines={2} mb={3}>
                        {story.description}
                      </Text>
                      <HStack mb={3}>
                        <Avatar size="xs" name={story.name} />
                        <Text fontSize="sm" color={mutedTextColor}>
                          {story.name}
                        </Text>
                      </HStack>
                      {story.tags && (
                        <HStack spacing={2} wrap="wrap">
                          {story.tags.map((tag, idx) => (
                            <Tag size="sm" key={idx} colorScheme="teal" variant="subtle">
                              <TagLabel>{tag}</TagLabel>
                            </Tag>
                          ))}
                        </HStack>
                      )}
                    </CardBody>
                    <CardFooter pt={0}>
                      <Link color={accentColor}>Read Full Story →</Link>
                    </CardFooter>
                  </Card>
                ))}
              </SimpleGrid>
            </Box>
          )}

          <Grid templateColumns={{ base: "1fr", lg: "2fr 1fr" }} gap={8}>
            {/* Main Content Area */}
            <GridItem>
              {/* Submission Form */}
              <Card mb={10} variant="outline">
                <CardHeader bg={accentColor} color="white">
                  <Heading size="md">Share Your Experience</Heading>
                </CardHeader>
                <CardBody>
                  <VStack spacing={5} align="stretch">
                    <FormControl>
                      <FormLabel>Your Name</FormLabel>
                      <InputGroup>
                        <InputLeftElement pointerEvents="none">
                          <FaUserAlt color="gray.300" />
                        </InputLeftElement>
                        <Input 
                          placeholder="Your name" 
                          value={name} 
                          onChange={e => setName(e.target.value)} 
                        />
                      </InputGroup>
                    </FormControl>
                    
                    <FormControl>
                      <FormLabel>Story Title</FormLabel>
                      <InputGroup>
                        <InputLeftElement pointerEvents="none">
                          <FaHeading color="gray.300" />
                        </InputLeftElement>
                        <Input 
                          placeholder="Give your story a title" 
                          value={title} 
                          onChange={e => setTitle(e.target.value)} 
                        />
                      </InputGroup>
                    </FormControl>
                    
                    <FormControl>
                      <FormLabel>Short Description</FormLabel>
                      <InputGroup>
                        <Textarea
                          placeholder="Write a brief summary of your story (1-2 sentences)"
                          value={description}
                          onChange={e => setDescription(e.target.value)}
                          rows={3}
                        />
                      </InputGroup>
                    </FormControl>
                    
                    <FormControl>
                      <FormLabel>Add Photos</FormLabel>
                      <Button 
                        leftIcon={<FaCamera />} 
                        variant="outline" 
                        as="label" 
                        mb={4} 
                        cursor="pointer"
                      >
                        Upload Images
                        <Input
                          type="file"
                          accept="image/*"
                          multiple
                          onChange={handleImageUpload}
                          hidden
                        />
                      </Button>
                      
                      {images.length > 0 && (
                        <SimpleGrid columns={{ base: 3, sm: 4 }} spacing={3}>
                          {images.map((img, idx) => (
                            <Box key={idx} position="relative">
                              <Image 
                                src={img} 
                                alt={`Upload ${idx}`} 
                                boxSize="80px" 
                                objectFit="cover" 
                                borderRadius="md" 
                              />
                              <IconButton
                                icon={<CloseIcon />}
                                size="xs"
                                position="absolute"
                                top="0"
                                right="0"
                                aria-label="Remove image"
                                onClick={() => handleRemoveImage(idx)}
                              />
                            </Box>
                          ))}
                        </SimpleGrid>
                      )}
                    </FormControl>
                    
                    <FormControl>
                      <FormLabel>Add Tags</FormLabel>
                      <HStack mb={2}>
                        <Input
                          placeholder="Add a tag"
                          value={newTag}
                          onChange={e => setNewTag(e.target.value)}
                          onKeyPress={e => e.key === 'Enter' && addTag()}
                        />
                        <Button onClick={addTag} leftIcon={<AddIcon />}>
                          Add
                        </Button>
                      </HStack>
                      
                      {tags.length > 0 && (
                        <HStack spacing={2} wrap="wrap">
                          {tags.map((tag, idx) => (
                            <Tag size="md" key={idx} borderRadius="full" variant="solid" colorScheme="teal">
                              <TagLabel>{tag}</TagLabel>
                              <CloseIcon
                                boxSize="12px"
                                cursor="pointer"
                                ml={1}
                                onClick={() => removeTag(tag)}
                              />
                            </Tag>
                          ))}
                        </HStack>
                      )}
                    </FormControl>
                    
                    <FormControl>
                      <FormLabel>Your Story</FormLabel>
                      <InputGroup>
                        <Textarea
                          placeholder="Share your full experience..."
                          value={content}
                          onChange={e => setContent(e.target.value)}
                          rows={8}
                        />
                      </InputGroup>
                    </FormControl>
                    
                    <Button
                      leftIcon={<FaPen />}
                      colorScheme="teal"
                      size="lg"
                      onClick={handleSubmit}
                    >
                      Submit Your Story
                    </Button>
                  </VStack>
                </CardBody>
              </Card>

              {/* Community Stories */}
              <Box>
                <Heading as="h2" size="lg" mb={6}>
                  Community Stories
                </Heading>
                <VStack spacing={6} align="stretch">
                  {stories.filter(s => s.status === STORY_STATUS.APPROVED).length > 0 ? (
                    stories
                      .filter(s => s.status === STORY_STATUS.APPROVED)
                      .map((story, i) => (
                        <Card key={i} variant="outline" overflow="hidden">
                          <CardHeader pb={0}>
                            <Flex justify="space-between" align="center" mb={2}>
                              <Flex align="center" gap={2}>
                                <Avatar name={story.name} size="sm" />
                                <Box>
                                  <Text fontWeight="bold">{story.name}</Text>
                                  <Text fontSize="xs" color={mutedTextColor}>
                                    {story.timestamp}
                                  </Text>
                                </Box>
                              </Flex>
                              <HStack>
                                <Tag size="sm" variant="subtle" colorScheme="cyan">
                                  <TagLeftIcon boxSize="12px" as={TimeIcon} />
                                  <TagLabel>{Math.floor(Math.random() * 10) + 2} min read</TagLabel>
                                </Tag>
                              </HStack>
                            </Flex>
                            <Heading size="md" mt={2}>{story.title}</Heading>
                          </CardHeader>
                          
                          <CardBody pt={3}>
                            {story.location && (
                              <HStack color={mutedTextColor} mb={3} fontSize="sm">
                                <FaMapMarkerAlt />
                                <Text>{story.location}</Text>
                              </HStack>
                            )}

                            <Text fontWeight="medium" fontSize="md" mb={3}>
                              {story.description}
                            </Text>
                            
                            {story.images && story.images.length > 0 && (
                              <Box mb={4}>
                                <SimpleGrid columns={{ base: 1, sm: story.images.length > 1 ? 2 : 1 }} spacing={3}>
                                  {story.images.slice(0, 4).map((img, idx) => (
                                    <Image
                                      key={idx}
                                      src={img}
                                      alt={`Story image ${idx}`}
                                      objectFit="cover"
                                      borderRadius="md"
                                      maxH="300px"
                                      w="100%"
                                    />
                                  ))}
                                  {story.images.length > 4 && (
                                    <Box 
                                      position="relative" 
                                      borderRadius="md" 
                                      overflow="hidden"
                                    >
                                      <Image
                                        src={story.images[4]}
                                        alt={`Story image 4`}
                                        objectFit="cover"
                                        maxH="300px"
                                        w="100%"
                                        filter="brightness(50%)"
                                      />
                                      <Text 
                                        position="absolute" 
                                        top="50%" 
                                        left="50%"
                                        transform="translate(-50%, -50%)" 
                                        color="white" 
                                        fontWeight="bold"
                                      >
                                        +{story.images.length - 4} more
                                      </Text>
                                    </Box>
                                  )}
                                </SimpleGrid>
                              </Box>
                            )}
                            
                            <Text mt={2} noOfLines={3}>
                              {story.content}
                            </Text>
                            
                            <Link color={accentColor} fontWeight="medium" display="block" mt={3}>
                              Read Full Story →
                            </Link>
                          </CardBody>
                          
                          <CardFooter 
                            bg={useColorModeValue('gray.50', 'gray.700')} 
                            borderTop="1px" 
                            borderColor={borderColor}
                          >
                            <HStack spacing={4}>
                              <Button variant="ghost" leftIcon={<StarIcon />}>
                                {story.likes || Math.floor(Math.random() * 50)}
                              </Button>
                              <Button variant="ghost" leftIcon={<ChatIcon />}>
                                {Math.floor(Math.random() * 20)} Comments
                              </Button>
                              <Button variant="ghost" leftIcon={<InfoIcon />}>
                                {story.views || Math.floor(Math.random() * 100) + 50} Views
                              </Button>
                            </HStack>
                          </CardFooter>
                        </Card>
                      ))
                  ) : (
                    <Box p={10} textAlign="center" borderRadius="md" borderWidth="1px">
                      <Heading size="md" mb={4} color={mutedTextColor}>No stories approved yet</Heading>
                      <Text color={mutedTextColor}>Be the first to share your experience!</Text>
                    </Box>
                  )}
                </VStack>
              </Box>
            </GridItem>

            {/* Sidebar */}
            <GridItem>
              {/* Search Box */}
              <Card mb={6} variant="outline">
                <CardBody>
                  <InputGroup mb={4}>
                    <InputLeftElement pointerEvents="none">
                      <SearchIcon color="gray.300" />
                    </InputLeftElement>
                    <Input placeholder="Search stories..." />
                  </InputGroup>
                  <Text fontSize="sm" color={mutedTextColor}>
                    Try searching for topics, locations, or keywords
                  </Text>
                </CardBody>
              </Card>

              {/* Premium Ad */}
              <Card 
                mb={6} 
                bgGradient="linear(to-r, purple.500, pink.500)" 
                color="white"
              >
                <CardBody p={6}>
                  <Text fontSize="sm" fontWeight="bold" mb={2}>SPONSORED</Text>
                  <Heading size="md" mb={3}>Premium Experience</Heading>
                  <Text mb={4}>
                    Upgrade today for exclusive stories, premium features, and ad-free browsing.
                  </Text>
                  <Button colorScheme="whiteAlpha">Learn More</Button>
                </CardBody>
              </Card>

              {/* Newsletter Signup */}
              <Card mb={6} variant="outline">
                <CardHeader pb={0}>
                  <Heading size="md">Get Weekly Updates</Heading>
                </CardHeader>
                <CardBody>
                  <Text mb={4}>
                    Subscribe to our newsletter for the best stories delivered to your inbox.
                  </Text>
                  <InputGroup mb={3}>
                    <InputLeftElement pointerEvents="none">
                      <AtSignIcon color="gray.300" />
                    </InputLeftElement>
                    <Input placeholder="Your email address" />
                  </InputGroup>
                  <Button colorScheme="teal" w="full">Subscribe</Button>
                </CardBody>
              </Card>

              {/* Popular Tags */}
              <Card mb={6} variant="outline">
                <CardHeader pb={0}>
                  <Heading size="md">Popular Tags</Heading>
                </CardHeader>
                <CardBody>
                  <HStack spacing={2} wrap="wrap">
                    {['Travel', 'Personal Growth', 'Adventure', 'Life Lessons', 'Career', 'Family', 'Relationships', 'Health'].map((tag, i) => (
                      <Tag key={i} size="md" variant="subtle" colorScheme="teal" mb={2} cursor="pointer">
                        <TagLabel>{tag}</TagLabel>
                      </Tag>
                    ))}
                  </HStack>
                </CardBody>
              </Card>

              {/* Standard Ad */}
              <Card mb={6} variant="filled" bg="gray.200">
                <CardBody>
                  <Text fontSize="xs" color="gray.500" mb={2}>ADVERTISEMENT</Text>
                  <Box bg="white" p={4} borderRadius="md" textAlign="center">
                    <Heading size="sm" mb={2}>Brand Spotlight</Heading>
                    <Text fontSize="sm">Custom promotional content would appear here.</Text>
                  </Box>
                </CardBody>
              </Card>

              {/* Related Content */}
              <Card variant="outline">
                <CardHeader pb={0}>
                  <Heading size="md">You Might Also Like</Heading>
                </CardHeader>
                <CardBody>
                  <VStack spacing={4} align="stretch">
                    {[1, 2, 3].map(i => (
                      <HStack key={i} spacing={3}>
                        <Box boxSize="60px" bg="gray.200" borderRadius="md"></Box>
                        <Box>
                          <Text fontWeight="medium" noOfLines={2}>
                            Related story title that might interest readers
                          </Text>
                          <Text fontSize="xs" color={mutedTextColor}>
                            {Math.floor(Math.random() * 10) + 1} days ago
                          </Text>
                        </Box>
                      </HStack>
                    ))}
                  </VStack>
                </CardBody>
              </Card>
            </GridItem>
          </Grid>

          {/* CTA Section */}
          <Box 
            mt={16} 
            bg={accentColor} 
            color="white" 
            p={8} 
            borderRadius="lg"
            textAlign="center"
          >
            <Heading size="lg" mb={4}>Ready to share your story?</Heading>
            <Text mb={6} maxW="container.md" mx="auto">
              Your experiences matter. Join our growing community of storytellers and connect 
              with others through authentic experiences.
            </Text>
            <Button 
              size="lg" 
              colorScheme="whiteAlpha" 
              onClick={() => window.scrollTo({ top: 0, behavior: 'smooth' })}
            >
              Start Writing
            </Button>
          </Box>
          
      
        </Container>
      </Box>
    </>
  );
}